@@ -3,5 +3,5 @@
 #
 GNOMECANVASPIXBUF_LIBDIR="-L/usr/X11R6/lib"
 GNOMECANVASPIXBUF_LIBS="-L/usr/local/lib -lgmodule12 -lglib12 -ldl -lgdk_pixbuf -L/usr/X11R6/lib -L/usr/X11R6/lib -lgtk12 -lgdk12 -L/usr/local/lib -lgmodule12 -lglib12 -ldl -lintl -lxpg4 -lXext -lX11 -lm -lgnomecanvaspixbuf"
-GNOMECANVASPIXBUF_INCLUDEDIR="-I/usr/X11R6/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include"
-MODULE_VERSION="gnomecanvaspixbuf-0.11.0"
+GNOMECANVASPIXBUF_INCLUDEDIR="-I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include"
+MODULE_VERSION="gnomecanvaspixbuf-0.13.0"
